@@ -96,6 +96,7 @@ hardwired_t hw[] = {
   { "autopurgeup", 0, 0, 0, "# time to delete stopped items from upload list" },
   { "autopurgedown", 0, 0, 0, "# time to delete stopped items from download list" },
   { "autoreply", 0, 0, 0, "# a string to send as an automatic reply to incoming user messages" },
+  { "autorestart", 0, 0, &info.autorestart, "# automatically reconnect when connection to server lost?" },
   { "connecttimeout", 0, 0, 0, "# timeout after this many seconds while connecting to server" },
   { "cursorfollowsscreen", 0, 0, 0, "# should PgUp and PgDn move the screen, rather than the cursor, on the\n# search result screen?" },
   { "debug", 0, 0, 0, "# debug level" },
@@ -103,7 +104,7 @@ hardwired_t hw[] = {
   { "libraryfile", 1, &info.shared_filename, 0, "# location of your library file" },
   { "metaserver", 0, 0, 0, "# URL of a napigator-style metaserver" },
   { "metatimeout", 0, 0, 0, "# timeout for connecting to metaserver" },
-  { "napping", 0, 0, 0, "# relative or absolute filename of the napping program to use\n" },
+  { "napping", 0, 0, 0, "# relative or absolute filename of the napping program to use" },
   { "newstimeout", 0, 0, 0, "# timeout for retrieving news" },
   { "noechosets", 0, 0, 0, "# should the /set command be quiet?" },
   { "nometa", 0, 0, 0, "# skip connecting to metaserver on startup?" },
