@@ -60,6 +60,13 @@ struct scount_s
 };
 typedef struct scount_s scount_t;
 
+struct stringlist_s
+{
+  char *s;
+  struct stringlist_s *next;
+};
+typedef struct stringlist_s stringlist_t;
+
 /* ---------------------------------------------------------------------- */
 /* the data structure for search result items. Note: the convention is
    that the items of the search result list are numbered sequentially,
@@ -160,8 +167,13 @@ typedef struct itag_s itag_t;
    [no state]: user download request (if limit exceeded) -> create
    task -> QUEUED
 
-   [no state]: user download request (if limit ok) -> create task ->
-   send 203 (download request) to server -> REQUESTED
+   [no state]: user download request (if limit ok, and there is not
+   already an R*QUEUED item by this nick) -> create task -> send 203
+   (download request) to server -> REQUESTED
+
+   [no state]: user download request (if limit ok, and there is
+   already an R*QUEUED item by this nick) -> create task -> RQUEUED
+   (with timer set to retry this item).
 
    QUEUED: (when a slot becomes available) -> send 203 (download
    request) to server -> REQUESTED
@@ -173,14 +185,20 @@ typedef struct itag_s itag_t;
 
    REQUESTED or RRQUEUED: receive 609 (accept failure) from server -> FAILED
 
-   REQUESTED or RRQUEUED: receive 620 (queue limit) from server -> RQUEUED (with
-   timer set to retry this item).
+   REQUESTED or RRQUEUED: receive 620 (queue limit) from server (if
+   remote upload limit >= 1) -> RQUEUED (with timer set to retry this
+   item).
 
-   REQUESTED or RRQUEUED: receive 204 (download ack) from server (if remote party
-   is firewalled) -> send 500 (alt download request) to server -> WAITING
+   REQUESTED or RRQUEUED: receive 620 (queue limit) from server (if
+   remote upload limit <= 0) -> FAILED
 
-   REQUESTED or RRQUEUED: receive 204 (download ack) from server (if remote party
-   is not firewalled) -> contact remote client -> CONNECTING
+   REQUESTED or RRQUEUED: receive 204 (download ack) from server (if
+   remote party is firewalled) -> send 500 (alt download request) to
+   server -> WAITING
+
+   REQUESTED or RRQUEUED: receive 204 (download ack) from server (if
+   remote party is not firewalled) -> contact remote client ->
+   CONNECTING
 
    REQUESTED: (timed out) -> resend 203 to server -> REQUESTED
 
@@ -446,6 +464,8 @@ O_NAP_FUNC(dpart);
 O_NAP_FUNC(dquit);
 O_NAP_FUNC(dtell);
 O_NAP_FUNC(dwhois);
+O_NAP_FUNC(dfup);
+O_NAP_FUNC(dfdown);
 O_NAP_FUNC(dpup);
 O_NAP_FUNC(dpdown);
 O_NAP_FUNC(dsearch);
