@@ -11,6 +11,7 @@
 #endif
 #include <string.h>
 #include <errno.h>
+#include <sys/types.h>
 #include <sys/socket.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -34,6 +35,10 @@
   #include "wind.h"
 #endif
 
+#ifdef MEMWATCH
+  #include "memwatch.h"
+#endif
+
 extern upload_t *up;
 extern download_t *down;
 extern info_t info; 
@@ -226,8 +231,8 @@ int lsock(WINDOW *win, sock_t *m)
      * a broken client like Napster v2.0 BETA 9.6 will send a SENDLIST and
      * nothing else. As a result, dosendlist will never be called, and the 
      * socket will remain open until the program quits. */
-    free(m->nm);
-    m->nm = strdup("sendlist");
+    free(m->socknm);
+    m->socknm = strdup("sendlist");
     m->func = dosendlist;
   }
   else              /* note: trailing "else" goes with following "if"!! */
@@ -380,8 +385,8 @@ int doget(WINDOW *win, sock_t *m)
   bandwidth_init(&m->bw);
   m->func = sfile;
   m->t = S_W;
-  free(m->nm);
-  m->nm = strdup(gnum(1));
+  free(m->socknm);
+  m->socknm = strdup(gnum(1));
   
   sv = findsock("server");
   if (sv)
@@ -529,8 +534,8 @@ int dosend(WINDOW *win, sock_t *m)
   task->state = IN_PROGRESS;
 
   /* rename connection from "conn" to "d #", and connect it to this task */
-  free(m->nm);
-  m->nm = strdup(gnum(0));
+  free(m->socknm);
+  m->socknm = strdup(gnum(0));
   m->dtask = task;
   m->bwlimit = 1;
   bandwidth_init(&m->bw);
@@ -846,7 +851,7 @@ int gsize(WINDOW *win, sock_t *m)
   /* we need the debugging code here, since we didn't call rsock for this */
   if (nvar("debug") == 2)
   {
-    wp(win, ""DARK GREEN"<-- [from %d=%s] <%s>"WHITE"\n", s, m->nm, quote(buf));
+    wp(win, ""DARK GREEN"<-- [from %d=%s] <%s>"WHITE"\n", s, m->socknm, quote(buf));
     drw(win);
   }
   
@@ -934,7 +939,7 @@ int sfile(WINDOW *win, sock_t *m)
     wp(win, "* Transfer interrupted while sending \"%s\" to %s (%lu of %lu bytes in %d seconds): %s\n", task->fn, task->nick, task->pos-task->bsz, task->size-task->bsz, t-task->p_time, r ? strerror(errno) : "connection lost?");
     drw(win);
     
-    if (r && errno==EPIPE && nvar("tracksigpipes")==1) {
+    if (r && errno==EPIPE && nvar_default("tracksigpipes", 0)) {
       wp(win, "### SIGPIPE debug message: fingering user %s to see whether a particular client causes more sigpipes than others.\n", task->nick);
       drw(win);
       sk = findsock("server");
@@ -1076,7 +1081,7 @@ int glist(WINDOW *win, sock_t *m)
     if (nvar("debug") == 2) {
       /* trailing newline was already stripped, so it won't show up here */
       wp(win, ""DARK GREEN"<-- [from %d=%s] <%s>"WHITE"\n", m->fd, \
-          m->nm, quote(buf));
+          m->socknm, quote(buf));
       drw(win);
     }
     tok = form_tokso(buf, &cnt);
@@ -1131,7 +1136,7 @@ int dosendlist(WINDOW *win, sock_t *m)
   if (!nick || strcasecmp(directbrowse.nick, nick) != 0) {
     if (nvar("debug") == 2) {
       wp(win, ""DARK GREEN"<-- [from %d=%s] Got unexpected SENDLIST from %s"\
-          " (%s)"WHITE"\n", m->fd, m->nm, nick ? quote(nick):"?", \
+          " (%s)"WHITE"\n", m->fd, m->socknm, nick ? quote(nick):"?", \
           getpeerip(m->fd));
       drw(win);
     }
@@ -1145,12 +1150,12 @@ int dosendlist(WINDOW *win, sock_t *m)
   free(nick);
 
   /* rename the connection */
-  free(m->nm);
-  m->nm = strdup("dirbrowse");
+  free(m->socknm);
+  m->socknm = strdup("dirbrowse");
   
   if (nvar("debug") == 2) {
     wp(win, ""DARK GREEN"<-- [from %d=%s] Got SENDLIST from %s"WHITE"\n", \
-        m->fd, m->nm, directbrowse.nick);
+        m->fd, m->socknm, directbrowse.nick);
   }
   wp(win, "* Receiving shared file list from %s...\n", directbrowse.nick);
   drw(win);
@@ -1174,13 +1179,13 @@ int dogetlist(WINDOW *win, sock_t *m)
    * check that we are within the limit here. */
 
   if (nvar("debug") == 2) {
-    wp(win, ""DARK GREEN"<-- [from %d=%s] Got GETLIST"WHITE"\n", m->fd, m->nm);
+    wp(win, ""DARK GREEN"<-- [from %d=%s] Got GETLIST"WHITE"\n", m->fd, m->socknm);
     drw(win);
   }
 
   /* rename the connection to "b #", where # is an integer */
-  free(m->nm);
-  m->nm = strdup(gnum(2));
+  free(m->socknm);
+  m->socknm = strdup(gnum(2));
 
   /* send "<mynick>\n" */
   r = ssock(s, "%s\n", info.user);
@@ -1195,7 +1200,7 @@ int dogetlist(WINDOW *win, sock_t *m)
   }       
   
   if (info.shared_filename) {
-    libraryfile = info.shared_filename;
+    libraryfile = strdup(info.shared_filename);
   } else {
     libraryfile = home_file(LIBRARYFILE);
   }
@@ -1208,8 +1213,10 @@ int dogetlist(WINDOW *win, sock_t *m)
       drw(win);
     }
     delsock(m->fd);
+    free(libraryfile);
     return(1);
   }
+  free(libraryfile);
   
   m->btask = (outbrowse_t *) malloc(sizeof(outbrowse_t));
   m->btask->g = g;
@@ -1258,7 +1265,7 @@ int initsendlist(WINDOW *win, sock_t *m)
   }
   
   if (info.shared_filename) {
-    libraryfile = info.shared_filename;
+    libraryfile = strdup(info.shared_filename);
   } else {
     libraryfile = home_file(LIBRARYFILE);
   }
@@ -1271,8 +1278,10 @@ int initsendlist(WINDOW *win, sock_t *m)
       drw(win);
     }
     delsock(m->fd);
+    free(libraryfile);
     return(1);
   }
+  free(libraryfile);
 
   m->btask = (outbrowse_t *) malloc(sizeof(outbrowse_t));
   m->btask->g = g;
