@@ -453,50 +453,50 @@ mhdr_t *ogginfo(char *fn, int md5blocks)
   int f;
   mhdr_t *r;
   struct stat st;
+  int res;
 
   /* get file stats and read first 58 bytes */
   f = open(fn, O_RDONLY);
   if (f == -1) {
-    return NULL;
+    return NULL;goto fail;
   }
   fstat(f, &st);
   n = read(f, buf, 58);
-  close(f);
 
   if (n<58) {
-    return NULL;
+    goto fail;
   }
   
   /* check that this is a first page of a logical ogg stream. We don't
      bother checking the CRC checksum */
   if (strncmp(&buf[0], "OggS", 4) != 0) {        /* capture pattern */
-    return NULL;
+    goto fail;
   }
   if (buf[4] != 0) {                             /* stream structure version */
-    return NULL;
+    goto fail;
   }
   if ((buf[5] & 3) != 2) {                       /* ogg header type flag */
-    return NULL;
+    goto fail;
   }
   if (buf[18] || buf[19] || buf[20] || buf[21]) {/* page sequence no. */
-    return NULL;                                 
+    goto fail;                                 
   }
   if (buf[26] != 1 || buf[27] != 30) {           /* segment table */
-    return NULL;
+    goto fail;
   }
 
   /* check that this is a vorbis "1" header */
   if (buf[28] != 1) {                            /* vorbis packet type */
-    return NULL;
+    goto fail;
   }
   if (strncmp(&buf[29], "vorbis", 6) != 0) {     /* vorbis packet identifier */
-    return NULL;
+    goto fail;
   }
   if (buf[35] || buf[36] || buf[37] || buf[38]) {/* vorbis version */
-    return NULL;                                 
+    goto fail;                                 
   }
-  if ((buf[57] & 1) != 1) {                        /* EOP check */
-    return NULL;
+  if ((buf[57] & 1) != 1) {                      /* EOP check */
+    goto fail;
   }
   
   /* seems we found an okay vorbis packet, now read the data. We
@@ -505,7 +505,7 @@ mhdr_t *ogginfo(char *fn, int md5blocks)
 
   r = (mhdr_t *)malloc(sizeof(mhdr_t));
   if (!r) {   
-    return NULL;   /* out of memory; fail silently */
+    goto fail;   /* out of memory; fail silently */
   }
 
   /* channels = buf[39]; */
@@ -522,9 +522,18 @@ mhdr_t *ogginfo(char *fn, int md5blocks)
 
   /* calculate checksum */
   lseek(f, 0, SEEK_SET);
-  md5hash(r->check, f, md5blocks);
+  res = md5hash(r->check, f, md5blocks);
+  if (res) {
+    free(r);
+    goto fail;
+  }
 
+  close(f);
   return r;
+
+ fail:
+  close(f);
+  return NULL;
 }
 
 /* calculate md5 hash of the given stream, starting from the current
