@@ -66,7 +66,7 @@ chans_t *chanl = NULL, *curchan = NULL;
 hotlist_t *hlist = NULL;
 info_t info;          /* struct to hold some command line options */
 int cloaked = 0;      /* whether we are cloaked */
-int lpbrk=0, noresolv=0;
+int lpbrk=0, noresolv=0, reconnect=0;
 int ipcs[2];
 int dresize = 0;
 
@@ -121,6 +121,7 @@ void tresize(int dummy)
 
 void sigint(int dummy)
 {
+  int save_errno = errno;
   static time_t cct = 0;
 
   if ((time(NULL)-cct) <= 1)
@@ -128,6 +129,7 @@ void sigint(int dummy)
   
   cct = time(NULL);
   lpbrk = 1;
+  errno = save_errno;
 }
 
 /* the following is used as a signal "handler" if we just want the
@@ -137,6 +139,13 @@ void noop(int dummy)
   /* empty */
 }
 
+/* handle the USR1 signal. This should schedule the "reconnect" command. */
+
+void sigusr1(int dummy)
+{
+  reconnect = 1;
+}  
+
 void dochecks()
 {
   if (dresize)
@@ -760,7 +769,7 @@ void dopts(int argc, char **argv)
       info.daemon=1;
       break;
     case 'a':
-      info.autorestart=1;
+      chset("autorestart", "1");
       break;
     case 'd':
       chset("debug", optarg);
@@ -1219,7 +1228,8 @@ int main(int argc, char *argv[])
     
     url = getval("metaserver");
     if (!url) 
-      url = METASERVER;
+      /* "randomly" pick a metaserver. */
+      url = ((time(NULL) % 2) ? METASERVER_1 : METASERVER_2);
     
     timeout = nvar_default("metatimeout", METATIMEOUT);
     if (timeout<0)
@@ -1345,6 +1355,7 @@ int main(int argc, char *argv[])
 #ifdef MCURSES
   signal(SIGCONT, tresize);
 #endif
+  signal(SIGUSR1, sigusr1);
 
   if (!info.daemon) {
     signal(SIGINT, sigint);
