@@ -764,6 +764,7 @@ I_NAP_FUNC(soff)
 I_NAP_FUNC(sqlimit)
 {
   download_t *task;
+  int max;
 
   /* find matching REQUESTED or RRQUEUED item in the download list */
   list_find(task, down, !strcasecmp(task->nick, tok[0]) && !strcasecmp(task->rfn, tok[1]) && (task->state == REQUESTED || task->state == RRQUEUED));
@@ -772,8 +773,22 @@ I_NAP_FUNC(sqlimit)
     return(1);
   }
 
+  max = atoi(tok[3]);  /* maximal number of uploads the remote client allows */
+
+  if (max <= 0) { 
+    /* remote client allows no uploads - don't bother queueing */
+
+    wp(win, ""RED"* Unable to get \"%s\" from %s (remote client allows 0 uploads)"WHITE"\n", task->fn, task->nick);
+    drw(win);
+
+    task->state = FAILED;
+    task->d_time = time(0);
+
+    return(1);
+  }
+
   if (task->state == REQUESTED) {
-    wp(win, "* Remotely queued \"%s\" from %s.\n", task->fn, task->nick, tok[3]);
+    wp(win, "* Remotely queued \"%s\" from %s.\n", task->fn, task->nick);
     drw(win);
   }
 
@@ -787,7 +802,6 @@ I_NAP_FUNC(sqlimit)
 I_NAP_FUNC(snget)
 {
   download_t *task;
-  char *fn;
 
   /* find matching REQUESTED or RRQUEUED item in the download list */
   list_find(task, down, !strcasecmp(task->nick, tok[0]) && !strcasecmp(task->rfn, tok[1]) && (task->state == REQUESTED || task->state == RRQUEUED));
@@ -796,11 +810,8 @@ I_NAP_FUNC(snget)
     return(1);
   }
 
-  /* calculate short filename */
-  fn = ud_basename(tok[1]);
-
   wp(win, "%s* Unable to get \"%s\" from %s (206 get error)%s\n", RED, \
-      fn, tok[0], WHITE);
+     task->fn, tok[0], WHITE);
   drw(win);
   
   task->state = FAILED;
@@ -1156,7 +1167,7 @@ I_NAP_FUNC(sget)
   if (!rport && !info.port)
   {
     wp(win, "%s* Unable to get \"%s\" from %s because both parties are " \
-        "firewalled%s\n", RED, fn, tok[0], WHITE);
+        "firewalled%s\n", RED, task->fn, task->nick, WHITE);
     drw(win);
     task->state = FAILED;
     task->d_time = time(0);
