@@ -122,6 +122,7 @@ void searchscr(void)
   
   status = strdup("Use F1 or 'q' to return to the main screen. 'h' for help.");
   lk = 1;
+  cx = 0;
 
   plist();
 }
@@ -374,8 +375,10 @@ void plist()
   }
   
   wattron(swin, COLOR_PAIR(CPBR));
-  if (!status)
+  if (!status) {
     status = strdup("Status");
+    cx = 0;
+  }
   wmove(swin, LINES-1, 0);
   whline(swin, ' ', COLS);
   waddstr(swin, status+cx);
@@ -528,6 +531,7 @@ int shandlechar(chtype cbuf)
     if (search)
     {
       lk = 1;
+      cx = 0;
       list_nth(cur, search, num-1);
       if (cur)
       {
@@ -548,6 +552,10 @@ int shandlechar(chtype cbuf)
 	    msprintf(&status, "Queued %s", cur->song);
 	    wp(wchan, "* Queued download of \"%s\" from %s\n", cur->song, cur->cmp);	    
 	    break;
+	  case 3:
+	    msprintf(&status, "Remotely queued %s", cur->song);
+	    wp(wchan, "* Remotely queued download of \"%s\" from %s\n", cur->song, cur->cmp);	    
+	    break;
 	  case -1:
 	    msprintf(&status, "Already getting %s", cur->song);
 	    break;
