@@ -17,6 +17,10 @@
 #include "cmds.h"
 #include "lists.h"
 
+#ifdef MEMWATCH
+  #include "memwatch.h"
+#endif
+
 /* a list of scheduled events. Each carries a time when it is supposed
    to be performed, then deleted. */
 ntimer_t *timers;
